@@ -5,20 +5,21 @@
 // Sound parameters
 //
 #define QUISK_SC_SIZE		256
-#define QUISK_PATH_SIZE     256         // max file path length
-#define IP_SIZE				32
+#define QUISK_PATH_SIZE		256		// max file path length
+#define IP_SIZE			32
 #define MAX_FILTER_SIZE		10001
-#define BIG_VOLUME			2.2e9
-#define CLOSED_TEXT			"The sound device is closed."
-#define CLIP32				2147483647
-#define CLIP16				32767
+#define BIG_VOLUME		2.2e9
+#define CLOSED_TEXT		"The sound device is closed."
+#define CLIP32			2147483647
+#define CLIP16			32767
 #define SAMP_BUFFER_SIZE	66000		// size of arrays used to capture samples
-#define IMD_TONE_1			1200		// frequency of IMD test tones
-#define IMD_TONE_2			1600
-#define INTERP_FILTER_TAPS	85			// interpolation filter
+#define IMD_TONE_1		1200		// frequency of IMD test tones
+#define IMD_TONE_2		1600
+#define INTERP_FILTER_TAPS	85		// interpolation filter
 #define MIC_OUT_RATE		48000		// mic post-processing sample rate
-#define PA_LIST_SIZE 		16			// max number of pulseaudio devices
-#define QUISK_MAX_RECEIVERS	9			// max number of receiver channels
+#define PA_LIST_SIZE		16		// max number of pulseaudio devices
+#define QUISK_MAX_SUB_RECEIVERS		9	// Maximum number of sub-receiver channels in addition to the main receiver
+#define QUISK_INDEX_SUB_RX1		4	// Index of sub-receiver Rx1 in quiskPlaybackDevices
 #define START_CW_DELAY_MAX	250		// Maximum delay for start_cw_delay
 
 // Test the audio: 0 == No test; normal operation;
@@ -300,6 +301,7 @@ extern int n_modem_sample_rate;			// Receive data, decimate to modem_sample_rate
 extern int n_speech_sample_rate;		// Microphone decimate to speech_sample_rate, Freedv codec output data at modem_sample_rate, interpolate to 48000
 extern int quisk_start_cw_delay;		// milliseconds to delay output on serial or MIDI CW key down
 extern int quisk_start_ssb_delay;		// milliseconds to discard output for all modes except CW
+extern struct sound_dev * quiskPlaybackDevices[];	// array of Playback sound devices
 
 extern PyObject * quisk_set_spot_level(PyObject * , PyObject *);
 extern PyObject * quisk_get_tx_filter(PyObject * , PyObject *);
