@@ -2,6 +2,9 @@ from __future__ import absolute_import
 from __future__ import division
 #  ** This is the file quisk_conf_defaults.py which contains defaults for Quisk. **
 #  
+# NOTE: You probably do not want to use a configuration file. Configuration files are obsolete
+#       because almost all configuration is done from the configuration screens in Quisk.
+#
 # Please do not change this configuration file quisk_conf_defaults.py.
 # Instead copy one of the other quisk_conf_*.py files to your own
 # configuration file and make changes there.
@@ -43,6 +46,24 @@ import quisk_hardware_model as quisk_hardware
 # import n2adr.quisk_widgets as quisk_widgets
 quisk_widgets = None
 
+# This is a dictionary of data items that are in the radio_dict but are not defined below in the sections.
+# The value is a tuple (format name, default value).
+name2format = {
+  "digital_rx1_name":('text', ''), "digital_rx2_name":('text', ''), "digital_rx3_name":('text', ''),
+  "digital_rx4_name":('text', ''), "digital_rx5_name":('text', ''), "digital_rx6_name":('text', ''),
+  "digital_rx7_name":('text', ''), "digital_rx8_name":('text', ''), "digital_rx9_name":('text', ''),
+  "win_digital_rx1_name":('text', ''), "win_digital_rx2_name":('text', ''), "win_digital_rx3_name":('text', ''),
+  "win_digital_rx4_name":('text', ''), "win_digital_rx5_name":('text', ''), "win_digital_rx6_name":('text', ''),
+  "win_digital_rx7_name":('text', ''), "win_digital_rx8_name":('text', ''), "win_digital_rx9_name":('text', ''),
+  "lin_digital_rx1_name":('text', ''), "lin_digital_rx2_name":('text', ''), "lin_digital_rx3_name":('text', ''),
+  "lin_digital_rx4_name":('text', ''), "lin_digital_rx5_name":('text', ''), "lin_digital_rx6_name":('text', ''),
+  "lin_digital_rx7_name":('text', ''), "lin_digital_rx8_name":('text', ''), "lin_digital_rx9_name":('text', ''),
+}
+
+def __getattr__(name):	# provide default values for some names
+  if name in name2format:
+    return name2format[name][1]
+  raise AttributeError("'conf' object has no attribute '%s'" % name)
 
 
 
