@@ -50,10 +50,14 @@ struct sound_dev quisk_Playback;
 struct sound_dev quisk_MicPlayback;
 
 static struct sound_dev Capture, MicCapture, DigitalInput, DigitalOutput, RawSamplePlayback;
-struct sound_dev quisk_DigitalRx1Output;
+static struct sound_dev dr1, dr2, dr3, dr4, dr5, dr6, dr7, dr8, dr9;		// sound output for digital sub-receivers
 // These are arrays of all capture and playback devices, and MUST end with NULL:
 static struct sound_dev * CaptureDevices[] = {&Capture, &MicCapture, &DigitalInput, NULL};
-static struct sound_dev * PlaybackDevices[] = {&quisk_Playback, &quisk_MicPlayback, &DigitalOutput, &RawSamplePlayback, &quisk_DigitalRx1Output, NULL};
+struct sound_dev * quiskPlaybackDevices[QUISK_INDEX_SUB_RX1 + QUISK_MAX_SUB_RECEIVERS + 1] = {
+	&quisk_Playback, &quisk_MicPlayback, &DigitalOutput, &RawSamplePlayback,
+	&dr1, &dr2, &dr3, &dr4, &dr5, &dr6, &dr7, &dr8, &dr9,
+	NULL};
+
 static SOCKET radio_sound_socket = INVALID_SOCKET;		// send radio sound samples to a socket
 static SOCKET radio_sound_mic_socket = INVALID_SOCKET;	// receive mic samples from a socket
 static int radio_sound_nshorts;						// number of shorts (two bytes) to send
@@ -1135,10 +1139,10 @@ void quisk_close_sound(void)	// Called from sound thread
 #ifdef MS_WINDOWS
 	int cleanup = radio_sound_socket != INVALID_SOCKET || radio_sound_mic_socket != INVALID_SOCKET;
 #endif
-	quisk_close_sound_directx(CaptureDevices, PlaybackDevices);
-	quisk_close_sound_wasapi(CaptureDevices, PlaybackDevices);
+	quisk_close_sound_directx(CaptureDevices, quiskPlaybackDevices);
+	quisk_close_sound_wasapi(CaptureDevices, quiskPlaybackDevices);
 	quisk_close_sound_portaudio();
-	quisk_close_sound_alsa(CaptureDevices, PlaybackDevices);
+	quisk_close_sound_alsa(CaptureDevices, quiskPlaybackDevices);
 	quisk_close_sound_pulseaudio();
 	if (pt_sample_stop)
 		(*pt_sample_stop)();
@@ -1269,9 +1273,9 @@ PyObject * quisk_set_sound_name(PyObject * self, PyObject * args)	// Called from
 	if (!PyArg_ParseTuple (args, "iiies#es#", &index, &play, &driver, utf8, &description, &l1, utf8, &device_name, &l2))
 		return NULL;
 	if (play) {
-		strMcpy(PlaybackDevices[index]->name, description, QUISK_SC_SIZE);
-		strMcpy(PlaybackDevices[index]->device_name, device_name, QUISK_SC_SIZE);
-		PlaybackDevices[index]->driver = driver;
+		strMcpy(quiskPlaybackDevices[index]->name, description, QUISK_SC_SIZE);
+		strMcpy(quiskPlaybackDevices[index]->device_name, device_name, QUISK_SC_SIZE);
+		quiskPlaybackDevices[index]->driver = driver;
 	}
 	else {
 		strMcpy(CaptureDevices[index]->name, description, QUISK_SC_SIZE);
@@ -1284,6 +1288,29 @@ PyObject * quisk_set_sound_name(PyObject * self, PyObject * args)	// Called from
 	return Py_None;
 }
 
+static void set_digital_rx()	// Set playback devices for digital modes from sub-receivers
+{
+	int i;
+	char buf80[80];
+	struct sound_dev * rx_dev;
+
+	for (i = QUISK_INDEX_SUB_RX1; i < QUISK_INDEX_SUB_RX1 + QUISK_MAX_SUB_RECEIVERS; i++) {
+		rx_dev = quiskPlaybackDevices[i];
+		rx_dev->dev_errmsg[0] = 0;
+		rx_dev->dev_index = t_DigitalRx1Output;
+		snprintf(buf80, 80, "Digital Rx%d Output", i - QUISK_INDEX_SUB_RX1 + 1);
+		strMcpy(rx_dev->stream_description, buf80, QUISK_SC_SIZE);
+		rx_dev->sample_rate = 48000;
+		rx_dev->channel_I = 0;
+		rx_dev->channel_Q = 1;
+		set_num_channels (rx_dev);
+		rx_dev->average_square = 0;
+		rx_dev->stream_dir_record = 0;
+		rx_dev->read_frames = 0;
+		rx_dev->latency_frames = rx_dev->sample_rate * quisk_sound_state.latency_millisecs / 1000;
+	}
+}
+
 void quisk_open_sound(void)	// Called from GUI thread
 {
 	int i;
@@ -1306,7 +1333,6 @@ void quisk_open_sound(void)	// Called from GUI thread
 	DigitalInput.dev_errmsg[0] = 0;
 	DigitalOutput.dev_errmsg[0] = 0;
 	RawSamplePlayback.dev_errmsg[0] = 0;
-	quisk_DigitalRx1Output.dev_errmsg[0] = 0;
 	Capture.dev_index = t_Capture;
 	quisk_Playback.dev_index = t_Playback;
 	MicCapture.dev_index = t_MicCapture;
@@ -1314,7 +1340,8 @@ void quisk_open_sound(void)	// Called from GUI thread
 	DigitalInput.dev_index = t_DigitalInput;
 	DigitalOutput.dev_index = t_DigitalOutput;
 	RawSamplePlayback.dev_index = t_RawSamplePlayback;
-	quisk_DigitalRx1Output.dev_index = t_DigitalRx1Output;
+
+	set_digital_rx();
 
 	// Set stream descriptions. This is important for "deviceless" drivers like
 	// PulseAudio to be able to distinguish the streams from each other.
@@ -1326,10 +1353,9 @@ void quisk_open_sound(void)	// Called from GUI thread
 	MicCapture.stream_description[QUISK_SC_SIZE-1] = '\0';
 	strMcpy(quisk_MicPlayback.stream_description, "I/Q Tx Sample Output", QUISK_SC_SIZE);
 	quisk_MicPlayback.stream_description[QUISK_SC_SIZE-1] = '\0';
-	strMcpy(DigitalInput.stream_description, "External Digital Input", QUISK_SC_SIZE);
-	strMcpy(DigitalOutput.stream_description, "External Digital Output", QUISK_SC_SIZE);
+	strMcpy(DigitalInput.stream_description, "Digital Tx0 Input", QUISK_SC_SIZE);
+	strMcpy(DigitalOutput.stream_description, "Digital Rx0 Output", QUISK_SC_SIZE);
 	strMcpy(RawSamplePlayback.stream_description, "Raw Digital Output", QUISK_SC_SIZE);
-	strMcpy(quisk_DigitalRx1Output.stream_description, "Digital Rx1 Output", QUISK_SC_SIZE);
    
 	quisk_Playback.sample_rate = quisk_sound_state.playback_rate;		// Radio sound play rate
 	quisk_MicPlayback.sample_rate = quisk_sound_state.mic_playback_rate;
@@ -1349,10 +1375,6 @@ void quisk_open_sound(void)	// Called from GUI thread
 	RawSamplePlayback.sample_rate = quisk_sound_state.sample_rate;
 	RawSamplePlayback.channel_I = 0;
 	RawSamplePlayback.channel_Q = 1;
-	// Playback device for digital modes from sub-receivers
-	quisk_DigitalRx1Output.sample_rate = 48000;
-	quisk_DigitalRx1Output.channel_I = 0;
-	quisk_DigitalRx1Output.channel_Q = 1;
 
 	set_num_channels (&Capture);
 	set_num_channels (&quisk_Playback);
@@ -1361,9 +1383,8 @@ void quisk_open_sound(void)	// Called from GUI thread
 	set_num_channels (&DigitalInput);
 	set_num_channels (&DigitalOutput);
 	set_num_channels (&RawSamplePlayback);
-	set_num_channels (&quisk_DigitalRx1Output);
 
-	for (i = 0; (pPlay = PlaybackDevices[i]); i++) {
+	for (i = 0; (pPlay = quiskPlaybackDevices[i]); i++) {
 		pPlay->started = 0;
 		pPlay->cr_correction = 0;
 		pPlay->cr_delay = 3;
@@ -1380,7 +1401,6 @@ void quisk_open_sound(void)	// Called from GUI thread
 	DigitalInput.average_square = 0;
 	DigitalOutput.average_square = 0;
 	RawSamplePlayback.average_square = 0;
-	quisk_DigitalRx1Output.average_square = 0;
 
 	//Needed for pulse audio context connection (KM4DSJ)
 	Capture.stream_dir_record = 1;
@@ -1390,7 +1410,6 @@ void quisk_open_sound(void)	// Called from GUI thread
 	DigitalInput.stream_dir_record = 1;
 	DigitalOutput.stream_dir_record = 0;
 	RawSamplePlayback.stream_dir_record = 0;
-	quisk_DigitalRx1Output.stream_dir_record = 0;
 
 	//For remote IQ server over pulseaudio (KM4DSJ)
 	if (quisk_sound_state.IQ_server[0]) {
@@ -1428,8 +1447,6 @@ void quisk_open_sound(void)	// Called from GUI thread
 	DigitalInput.latency_frames = 0;
 	DigitalOutput.read_frames = 0;
 	DigitalOutput.latency_frames = DigitalOutput.sample_rate * quisk_sound_state.latency_millisecs / 1000;
-	quisk_DigitalRx1Output.read_frames = 0;
-	quisk_DigitalRx1Output.latency_frames = quisk_DigitalRx1Output.sample_rate * quisk_sound_state.latency_millisecs / 1000;
 	// set capture and playback for raw samples
 	RawSamplePlayback.read_frames = 0;
 	RawSamplePlayback.latency_frames = RawSamplePlayback.sample_rate * quisk_sound_state.latency_millisecs / 1000;
@@ -1445,11 +1462,11 @@ void quisk_start_sound(void)	// Called from sound thread
 		(*pt_sample_start)();
    
 	// Let the drivers see the devices and start them up if appropriate
-	quisk_start_sound_directx(CaptureDevices, PlaybackDevices);
-	quisk_start_sound_wasapi(CaptureDevices, PlaybackDevices);
-	quisk_start_sound_portaudio(CaptureDevices, PlaybackDevices);
-	quisk_start_sound_pulseaudio(CaptureDevices, PlaybackDevices);
-	quisk_start_sound_alsa(CaptureDevices, PlaybackDevices);
+	quisk_start_sound_directx(CaptureDevices, quiskPlaybackDevices);
+	quisk_start_sound_wasapi(CaptureDevices, quiskPlaybackDevices);
+	quisk_start_sound_portaudio(CaptureDevices, quiskPlaybackDevices);
+	quisk_start_sound_pulseaudio(CaptureDevices, quiskPlaybackDevices);
+	quisk_start_sound_alsa(CaptureDevices, quiskPlaybackDevices);
 	if (pt_sample_read) {	// Capture from SDR-IQ or UDP
 		quisk_sound_state.rate_min = quisk_Playback.rate_min;
 		quisk_sound_state.rate_max = quisk_Playback.rate_max;
@@ -1569,18 +1586,20 @@ static void AddCard(struct sound_dev * dev, PyObject * pylist)
 PyObject * quisk_sound_errors(PyObject * self, PyObject * args)
 {  // return a list of strings with card names and error counts
 	PyObject * pylist;
+	struct sound_dev * rx_dev;
 
 	if (!PyArg_ParseTuple (args, ""))
 		return NULL;
 	pylist = PyList_New(0);
 	AddCard(&Capture,	pylist);
 	AddCard(&MicCapture,	pylist);
-	AddCard(&DigitalInput,	pylist);
 	AddCard(&quisk_Playback,	pylist);
 	AddCard(&quisk_MicPlayback,	pylist);
-	AddCard(&DigitalOutput,	pylist);
 	AddCard(&RawSamplePlayback, pylist);
-	AddCard(&quisk_DigitalRx1Output, pylist);
+	AddCard(&DigitalInput,	pylist);
+	AddCard(&DigitalOutput,	pylist);
+	rx_dev = quiskPlaybackDevices[QUISK_INDEX_SUB_RX1];
+	AddCard(rx_dev, pylist);
 	return pylist;
 }
 
